@@ -44,71 +44,70 @@ class _AllAirBase(_TemplateSystem):
 
 
 class VAVEquipmentType(str, Enum):
-    vav_chill_gbr = 'VAV chiller with gas boiler reheat'
-    vav_chill_ashp = 'VAV chiller with central air source heat pump reheat'
-    vav_chill_dhw = 'VAV chiller with district hot water reheat'
-    vav_chill_pfp = 'VAV chiller with PFP boxes'
-    vav_chill_gcr = 'VAV chiller with gas coil reheat'
-    vav_ac_chill_gbr = 'VAV air-cooled chiller with gas boiler reheat'
-    vav_ac_chill_ashp = 'VAV air-cooled chiller with central air source heat pump reheat'
-    vav_ac_chill_dhw = 'VAV air-cooled chiller with district hot water reheat'
-    vav_ac_chill_pfp = 'VAV air-cooled chiller with PFP boxes'
-    vav_ac_chill_gcr = 'VAV air-cooled chiller with gas coil reheat'
-    vav_dcw_gbr = 'VAV district chilled water with gas boiler reheat'
-    vav_dcw_ashp = 'VAV district chilled water with central air source heat pump reheat'
-    vav_dcw_dhw = 'VAV district chilled water with district hot water reheat'
-    vav_dcw_pfp = 'VAV district chilled water with PFP boxes'
-    vav_dcw_gcr = 'VAV district chilled water with gas coil reheat'
+    vav_chill_gbr = 'VAV_Chiller_Boiler'
+    vav_chill_ashp = 'VAV_Chiller_ASHP'
+    vav_chill_dhw = 'VAV_Chiller_DHW'
+    vav_chill_pfp = 'VAV_Chiller_PFP'
+    vav_chill_gcr = 'VAV_Chiller_GasCoil'
+    vav_ac_chill_gbr = 'VAV_ACChiller_Boiler'
+    vav_ac_chill_ashp = 'VAV_ACChiller_ASHP'
+    vav_ac_chill_dhw = 'VAV_ACChiller_DHW'
+    vav_ac_chill_pfp = 'VAV_ACChiller_PFP'
+    vav_ac_chill_gcr = 'VAV_ACChiller_GasCoil'
+    vav_dcw_gbr = 'VAV_DCW_Boiler'
+    vav_dcw_ashp = 'VAV_DCW_ASHP'
+    vav_dcw_dhw = 'VAV_DCW_DHW'
+    vav_dcw_pfp = 'VAV_DCW_PFP'
+    vav_dcw_gcr = 'VAV_DCW_GasCoil'
 
 
 class PVAVEquipmentType(str, Enum):
-    pvav_gbr = 'PVAV with gas boiler reheat'
-    pvav_ashp = 'PVAV with central air source heat pump reheat'
-    pvav_dhw = 'PVAV with district hot water reheat'
-    pvav_pfp = 'PVAV with PFP boxes'
-    pvav_ger = 'PVAV with gas heat with electric reheat'
+    pvav_gbr = 'PVAV_Boiler'
+    pvav_ashp = 'PVAV_ASHP'
+    pvav_dhw = 'PVAV_DHW'
+    pvav_pfp = 'PVAV_PFP'
+    pvav_ger = 'PVAV_BoilerElectricReheat'
 
 
 class PSZEquipmentType(str, Enum):
-    psz_e_base = 'PSZ-AC with baseboard electric'
-    psz_gb_base = 'PSZ-AC with baseboard gas boiler'
-    psz_dhw_base = 'PSZ-AC with baseboard district hot water'
-    psz_guh = 'PSZ-AC with gas unit heaters'
-    psz_ec = 'PSZ-AC with electric coil'
-    psz_gc = 'PSZ-AC with gas coil'
-    psz_gb = 'PSZ-AC with gas boiler'
-    psz_ashp = 'PSZ-AC with central air source heat pump'
-    psz_dhw = 'PSZ-AC with district hot water'
-    psz_ac = 'PSZ-AC with no heat'
-    psz_dcw_e_base = 'PSZ-AC district chilled water with baseboard electric'
-    psz_dcw_gb_base = 'PSZ-AC district chilled water with baseboard gas boiler'
-    psz_dcw_dhw_base = 'PSZ-AC district chilled water with baseboard district hot water'
-    psz_dcw_guh = 'PSZ-AC district chilled water with gas unit heaters'
-    psz_dcw_ec = 'PSZ-AC district chilled water with electric coil'
-    psz_dcw_gc = 'PSZ-AC district chilled water with gas coil'
-    psz_dcw_gb = 'PSZ-AC district chilled water with gas boiler'
-    psz_dcw_ashp = 'PSZ-AC district chilled water with central air source heat pump'
-    psz_dcw_dhw = 'PSZ-AC district chilled water with district hot water'
-    psz_dcw_ac = 'PSZ-AC district chilled water with no heat'
-    psz_hp = 'PSZ-HP'
+    psz_e_base = 'PSZAC_ElectricBaseboard'
+    psz_gb_base = 'PSZAC_BoilerBaseboard'
+    psz_dhw_base = 'PSZAC_DHWBaseboard'
+    psz_guh = 'PSZAC_GasHeaters'
+    psz_ec = 'PSZAC_ElectricCoil'
+    psz_gc = 'PSZAC_GasCoil'
+    psz_gb = 'PSZAC_Boiler'
+    psz_ashp = 'PSZAC_ASHP'
+    psz_dhw = 'PSZAC_DHW'
+    psz_ac = 'PSZAC'
+    psz_dcw_e_base = 'PSZAC_DCW_ElectricBaseboard'
+    psz_dcw_gb_base = 'PSZAC_DCW_BoilerBaseboard'
+    psz_dcw_guh = 'PSZAC_DCW_GasHeaters'
+    psz_dcw_ec = 'PSZAC_DCW_ElectricCoil'
+    psz_dcw_gc = 'PSZAC_DCW_GasCoil'
+    psz_dcw_gb = 'PSZAC_DCW_Boiler'
+    psz_dcw_ashp = 'PSZAC_DCW_ASHP'
+    psz_dcw_dhw = 'PSZAC_DCW_DHW'
+    psz_dcw_ac = 'PSZAC_DCW'
+    psz_hp = 'PSZHP'
 
 
 class PTACEquipmentType(str, Enum):
-    ptac_e_base = 'PTAC with baseboard electric'
-    ptac_gb_base = 'PTAC with baseboard gas boiler'
-    ptac_dhw_base = 'PTAC with baseboard district hot water'
-    ptac_guh = 'PTAC with gas unit heaters'
-    ptac_ec = 'PTAC with electric coil'
-    ptac_gc = 'PTAC with gas coil'
-    ptac_gb = 'PTAC with gas boiler'
-    ptac_ashp = 'PTAC with central air source heat pump'
-    ptac_dhw = 'PTAC with district hot water'
-    ptac = 'PTAC with no heat'
+    ptac_e_base = 'PTAC_ElectricBaseboard'
+    ptac_gb_base = 'PTAC_BoilerBaseboard'
+    ptac_dhw_base = 'PTAC_DHWBaseboard'
+    ptac_guh = 'PTAC_GasHeaters'
+    ptac_ec = 'PTAC_ElectricCoil'
+    ptac_gc = 'PTAC_GasCoil'
+    ptac_gb = 'PTAC_Boiler'
+    ptac_ashp = 'PTAC_ASHP'
+    ptac_dhw = 'PTAC_DHW'
+    ptac = 'PTAC'
     pthp = 'PTHP'
 
 
 class FurnaceEquipmentType(str, Enum):
-    furnace = 'Forced air furnace'
+    furnace = 'Furnace'
 
 
 class VAV(_AllAirBase):
